# Examples

Usage examples for all pyedautils modules. See {doc}`../api/index` for the full API reference.

- {doc}`data_io` — Save and load data in CSV, pickle, JSON
- {doc}`geopy` — Geocoding, coordinate conversion, altitude lookup
- {doc}`plots` — Visualizations (Daily Profiles, Mollier h,x-diagram)
- {doc}`season` — Season detection (astronomical and meteorological)
- {doc}`meteo_swiss` — Find nearest MeteoSwiss weather station
